@@ -3,18 +3,18 @@ import sys
 
 def print_info() -> None:
     print(
-        "Type annotations for boto3.Imagebuilder 1.17.78\n"
-        "Version:         1.17.78\n"
-        "Builder version: 4.13.1\n"
+        "Type annotations for boto3.imagebuilder 1.17.80\n"
+        "Version:         1.17.80\n"
+        "Builder version: 4.14.0\n"
         "Docs:            https://pypi.org/project/mypy-boto3-imagebuilder/\n"
-        "Boto3 docs:      https://boto3.amazonaws.com/v1/documentation/api/1.17.78/reference/services/imagebuilder.html#Imagebuilder\n"
+        "Boto3 docs:      https://boto3.amazonaws.com/v1/documentation/api/1.17.80/reference/services/imagebuilder.html#imagebuilder\n"
         "Other services:  https://pypi.org/project/boto3-stubs/\n"
         "Changelog:       https://github.com/vemel/mypy_boto3_builder/releases"
     )
 
 
 def print_version() -> None:
-    print("1.17.78")
+    print("1.17.80")
 
 
 def main() -> None:
